==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QPropertyNodeRemovedChange.java <==
package io.qt.qt3d.core;


/**
 * <p>Used to notify when a node is removed from a property</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynoderemovedchange.html">Qt3DCore::QPropertyNodeRemovedChange</a></p>
 */
public class QPropertyNodeRemovedChange extends io.qt.qt3d.core.QStaticPropertyValueRemovedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynoderemovedchange.html#QPropertyNodeRemovedChange">Qt3DCore::QPropertyNodeRemovedChange::QPropertyNodeRemovedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)</a></p>
     */
    @Deprecated
    public QPropertyNodeRemovedChange(io.qt.qt3d.core.QNodeId subjectId, io.qt.qt3d.core.QNode node){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId, node);
    }
    
    @Deprecated
    private native static void initialize_native(QPropertyNodeRemovedChange instance, io.qt.qt3d.core.QNodeId subjectId, io.qt.qt3d.core.QNode node);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynoderemovedchange.html#metaObject">Qt3DCore::QPropertyNodeRemovedChange::metaObject()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QMetaObject metaObject(){
        return metaObject_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QMetaObject metaObject_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynoderemovedchange.html#removedNodeId">Qt3DCore::QPropertyNodeRemovedChange::removedNodeId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNodeId removedNodeId(){
        return removedNodeId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNodeId removedNodeId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QPropertyNodeRemovedChange(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.14-sources.jar: io/qt/qt3d/core/QPropertyNodeRemovedChange.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Used to notify when a node is removed from a property</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynoderemovedchange.html">Qt3DCore::QPropertyNodeRemovedChange</a></p>
 */
public class QPropertyNodeRemovedChange extends io.qt.qt3d.core.QStaticPropertyValueRemovedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynoderemovedchange.html#QPropertyNodeRemovedChange">Qt3DCore::QPropertyNodeRemovedChange::QPropertyNodeRemovedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)</a></p>
     */
    @Deprecated
    public QPropertyNodeRemovedChange(io.qt.qt3d.core.@NonNull QNodeId subjectId, io.qt.qt3d.core.@Nullable QNode node){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId, node);
    }
    
    @Deprecated
    private native static void initialize_native(QPropertyNodeRemovedChange instance, io.qt.qt3d.core.QNodeId subjectId, io.qt.qt3d.core.QNode node);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynoderemovedchange.html#metaObject">Qt3DCore::QPropertyNodeRemovedChange::metaObject()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject metaObject(){
        return metaObject_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QMetaObject metaObject_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertynoderemovedchange.html#removedNodeId">Qt3DCore::QPropertyNodeRemovedChange::removedNodeId()const</a></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId removedNodeId(){
        return removedNodeId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QNodeId removedNodeId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QPropertyNodeRemovedChange(QPrivateConstructor p) { super(p); } 
    
}
